ecosound.classification package
===============================

Submodules
----------

ecosound.classification.CrossValidation module
----------------------------------------------

.. automodule:: ecosound.classification.CrossValidation
   :members:
   :undoc-members:
   :show-inheritance:

ecosound.classification.classification module
---------------------------------------------

.. automodule:: ecosound.classification.classification
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ecosound.classification
   :members:
   :undoc-members:
   :show-inheritance:
